summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kcautoconfigmodule.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kcautoconfigmodule.h')
-rw-r--r--kopete/libkopete/kcautoconfigmodule.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/libkopete/kcautoconfigmodule.h b/kopete/libkopete/kcautoconfigmodule.h
index be76dc26..43f6e2d3 100644
--- a/kopete/libkopete/kcautoconfigmodule.h
+++ b/kopete/libkopete/kcautoconfigmodule.h
@@ -25,11 +25,11 @@
#include "kopete_export.h"
class KAutoConfig;
-class KConfig;
+class TDEConfig;
/**
* @short Convenience KCModule for creating config page handled with KAutoConfig
*
* This class makes it very easy to create a configuration page using KAutoConfig.
* All you need to do is create a class that is derived from KCAutoConfigModule, create your
@@ -50,41 +50,41 @@ class KConfig;
* @author Olivier Goffart <ogoffart(@)tisclinet.be>
* @since 3.2
*/
-class KOPETE_EXPORT KCAutoConfigModule : public KCModule
+class KOPETE_EXPORT KCAutoConfigModule : public TDECModule
{
Q_OBJECT
public:
/**
* Standard KCModule constructor. Use TDEGlobal::config()
*/
KCAutoConfigModule( TQWidget * parent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
/**
* Standard KCModule constructor. Use TDEGlobal::config()
*/
KCAutoConfigModule( TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor.
* @param config the KConfig to use
* @param instance TDEInstance object for this KCM
* @param parent parent widget
* @param args special arguments for this KCM
*
* @todo document what the args mean (inherited from KCModule?)
*/
- KCAutoConfigModule(KConfig* config, TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(TDEConfig* config, TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
/**
* Constructor, much like the one above, except with
* no instance and with a name.
* @param config the KConfig to use
* @param parent parent widget
* @param name name of the object
* @param args special arguments for this KCM
*/
- KCAutoConfigModule(KConfig* config, TQWidget * parent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
+ KCAutoConfigModule(TDEConfig* config, TQWidget * parent = 0, const char * name=0 , const TQStringList & args = TQStringList() );
~KCAutoConfigModule();
@@ -114,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the config from the configfile.
*
* You can also reimplement this method, but you should always call the parent KCModule::load()
* be sure you know what you are doing
*/
virtual void load();
@@ -122,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Save the config to the configfile.
*
* You can also reimplement this method, but you should always call the parent KCModule::save()
* be sure you know what you are doing
*/
virtual void save();
@@ -130,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
/**
* Reload the default config
*
* You can also reimplement this method, but you should always call the parent KCModule::defaults()
* be sure you know what you are doing
*/
virtual void defaults();
@@ -25,11 +25,11 @@
/**
- * @short Convenience KCModule for creating config page handled with KAutoConfig
+ * @short Convenience TDECModule for creating config page handled with KAutoConfig
*
* This class makes it very easy to create a configuration page using KAutoConfig.
@@ -50,41 +50,41 @@ class KConfig;
public:
/**
- * Standard KCModule constructor. Use TDEGlobal::config()
+ * Standard TDECModule constructor. Use TDEGlobal::config()
*/
KCAutoConfigModule( TQWidget * parent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
@@ -50,41 +50,41 @@ class KConfig;
KCAutoConfigModule( TQWidget * parent = 0, const char * name = 0, const TQStringList & args = TQStringList() );
/**
- * Standard KCModule constructor. Use TDEGlobal::config()
+ * Standard TDECModule constructor. Use TDEGlobal::config()
*/
KCAutoConfigModule( TDEInstance * instance, TQWidget * parent = 0, const TQStringList & args = TQStringList() );
@@ -50,41 +50,41 @@ class KConfig;
/**
* Constructor.
- * @param config the KConfig to use
+ * @param config the TDEConfig to use
* @param instance TDEInstance object for this KCM
* @param parent parent widget
@@ -50,41 +50,41 @@ class KConfig;
* @param args special arguments for this KCM
*
- * @todo document what the args mean (inherited from KCModule?)
+ * @todo document what the args mean (inherited from TDECModule?)
*/
@@ -50,41 +50,41 @@ class KConfig;
* Constructor, much like the one above, except with
* no instance and with a name.
- * @param config the KConfig to use
+ * @param config the TDEConfig to use
* @param parent parent widget
* @param name name of the object
@@ -114,7 +114,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the config from the configfile.
*
- * You can also reimplement this method, but you should always call the parent KCModule::load()
+ * You can also reimplement this method, but you should always call the parent TDECModule::load()
* be sure you know what you are doing
*/
@@ -122,7 +122,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Save the config to the configfile.
*
- * You can also reimplement this method, but you should always call the parent KCModule::save()
+ * You can also reimplement this method, but you should always call the parent TDECModule::save()
* be sure you know what you are doing
*/
@@ -130,7 +130,7 @@ class KOPETE_EXPORT KCAutoConfigModule : public KCModule
* Reload the default config
*
- * You can also reimplement this method, but you should always call the parent KCModule::defaults()
+ * You can also reimplement this method, but you should always call the parent TDECModule::defaults()
* be sure you know what you are doing
*/